==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/ru/coptic.js <==
define(
//begin v1.x content
{
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-second-relative+0": "сейчас",
	"field-quarter-relative+-1": "в прошлом квартале",
	"field-weekday": "день недели",
	"field-mon-narrow-relative+0": "в этот пн.",
	"field-mon-narrow-relative+1": "в след. пн.",
	"field-wed-relative+0": "в эту среду",
	"field-wed-relative+1": "в следующую среду",
	"field-week-short": "нед.",
	"field-tue-relative+-1": "в прошлый вторник",
	"field-year-short": "г.",
	"field-thu-narrow-relative+-1": "в прош. чт.",
	"field-hour-relative+0": "в этом часе",
	"field-quarter-narrow": "кв.",
	"field-fri-relative+-1": "в прошлую пятницу",
	"field-hour-short": "ч.",
	"field-wed-relative+-1": "в прошлую среду",
	"months-format-wide": [
		"Тот",
		"Бабэ",
		"Хатур",
		"Кихак",
		"Тубэ",
		"Амшир",
		"Барамхат",
		"Бармуда",
		"Башнас",
		"Бауна",
		"Абиб",
		"Мисра",
		"Наси"
	],
	"field-mon-short-relative+-1": "в прош. пн.",
	"field-thu-relative+-1": "в прошлый четверг",
	"field-era": "эра",
	"months-standAlone-wide": [
		"Тот",
		"Бабэ",
		"Хатур",
		"Кихак",
		"Тубэ",
		"Амшир",
		"Барамхат",
		"Бармуда",
		"Башнас",
		"Бауна",
		"Абиб",
		"Мисра",
		"Наси"
	],
	"field-sat-narrow-relative+0": "в эту сб.",
	"field-sat-narrow-relative+1": "в след. сб.",
	"field-year": "год",
	"field-hour": "час",
	"months-format-abbr": [
		"Тот",
		"Бабэ",
		"Хатур",
		"Кихак",
		"Тубэ",
		"Амшир",
		"Барамхат",
		"Бармуда",
		"Башнас",
		"Бауна",
		"Абиб",
		"Мисра",
		"Наси"
	],
	"field-sat-relative+0": "в эту субботу",
	"field-sat-relative+1": "в следующую субботу",
	"field-sat-short-relative+-1": "в прош. сб.",
	"field-minute-narrow": "мин",
	"field-day-relative+0": "сегодня",
	"field-day-relative+1": "завтра",
	"field-thu-relative+0": "в этот четверг",
	"field-mon-narrow-relative+-1": "в прош. пн.",
	"field-day-relative+2": "послезавтра",
	"field-wed-narrow-relative+0": "в эту ср.",
	"field-thu-relative+1": "в следующий четверг",
	"months-standAlone-abbr": [
		"Тот",
		"Бабэ",
		"Хатур",
		"Кихак",
		"Тубэ",
		"Амшир",
		"Барамхат",
		"Бармуда",
		"Башнас",
		"Бауна",
		"Абиб",
		"Мисра",
		"Наси"
	],
	"field-wed-narrow-relative+1": "в след. ср.",
	"field-mon-short-relative+0": "в этот пн.",
	"field-mon-short-relative+1": "в след. пн.",
	"field-wed-short-relative+-1": "в прош. ср.",
	"field-fri-narrow-relative+-1": "в прош. пт.",
	"field-hour-narrow": "ч",
	"field-tue-short-relative+0": "в этот вт.",
	"field-year-narrow": "г.",
	"field-tue-short-relative+1": "в след. вт.",
	"field-minute-short": "мин.",
	"field-day-narrow": "дн.",
	"field-wed-short-relative+0": "в эту ср.",
	"field-wed-short-relative+1": "в след. ср.",
	"field-sun-relative+0": "в это воскресенье",
	"field-sun-relative+1": "в следующее воскресенье",
	"field-minute": "минута",
	"field-month-short": "мес.",
	"field-dayperiod": "ДП/ПП",
	"field-day-relative+-1": "вчера",
	"field-day-relative+-2": "позавчера",
	"field-minute-relative+0": "в эту минуту",
	"field-week-narrow": "нед.",
	"field-wed-narrow-relative+-1": "в прош. ср.",
	"field-day-short": "дн.",
	"field-quarter-relative+0": "в текущем квартале",
	"field-quarter-relative+1": "в следующем квартале",
	"field-fri-relative+0": "в эту пятницу",
	"field-fri-relative+1": "в следующую пятницу",
	"field-day": "день",
	"field-second-narrow": "с",
	"field-zone": "часовой пояс",
	"field-year-relative+-1": "в прошлом году",
	"field-month-relative+-1": "в прошлом месяце",
	"field-thu-short-relative+0": "в этот чт.",
	"field-thu-short-relative+1": "в след. чт.",
	"field-quarter-narrow-relative+0": "тек. кв.",
	"field-quarter-narrow-relative+1": "след. кв.",
	"field-quarter": "квартал",
	"field-month": "месяц",
	"field-tue-relative+0": "в этот вторник",
	"field-quarter-short-relative+0": "текущий кв.",
	"field-tue-relative+1": "в следующий вторник",
	"field-quarter-short-relative+1": "следующий кв.",
	"field-fri-narrow-relative+0": "в эту пт.",
	"field-fri-narrow-relative+1": "в след. пт.",
	"field-fri-short-relative+-1": "в прош. пт.",
	"field-sun-narrow-relative+-1": "в прош. вс.",
	"field-quarter-short-relative+-1": "последний кв.",
	"field-sun-narrow-relative+0": "в это вс.",
	"field-thu-narrow-relative+0": "в этот чт.",
	"field-sun-narrow-relative+1": "в след. вс.",
	"field-thu-narrow-relative+1": "в след. чт.",
	"field-tue-narrow-relative+0": "в этот вт.",
	"field-mon-relative+0": "в этот понедельник",
	"field-tue-narrow-relative+1": "в след. вт.",
	"field-mon-relative+1": "в следующий понедельник",
	"field-tue-narrow-relative+-1": "в прош. вт.",
	"field-second-short": "сек.",
	"field-second": "секунда",
	"field-fri-short-relative+0": "в эту пт.",
	"field-sat-relative+-1": "в прошлую субботу",
	"field-fri-short-relative+1": "в след. пт.",
	"field-sun-relative+-1": "в прошлое воскресенье",
	"field-month-relative+0": "в этом месяце",
	"field-quarter-narrow-relative+-1": "посл. кв.",
	"field-month-relative+1": "в следующем месяце",
	"field-week": "неделя",
	"field-sat-short-relative+0": "в эту сб.",
	"field-sat-short-relative+1": "в след. сб.",
	"field-year-relative+0": "в этом году",
	"field-week-relative+-1": "на прошлой неделе",
	"field-year-relative+1": "в следующем году",
	"field-quarter-short": "кв.",
	"field-sun-short-relative+-1": "в прош. вс.",
	"field-thu-short-relative+-1": "в прош. чт.",
	"field-tue-short-relative+-1": "в прош. вт.",
	"field-mon-relative+-1": "в прошлый понедельник",
	"field-sat-narrow-relative+-1": "в прош. сб.",
	"field-month-narrow": "мес.",
	"field-week-relative+0": "на этой неделе",
	"field-sun-short-relative+0": "в это вс.",
	"field-week-relative+1": "на следующей неделе",
	"field-sun-short-relative+1": "в след. вс."
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/ru/coptic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "текущий кв.",
	"field-quarter-short-relative+1": "следующий кв.",
	"field-tue-relative+-1": "в прошлый вторник",
	"field-year": "год",
	"field-wed-relative+0": "в эту среду",
	"field-wed-relative+1": "в следующую среду",
	"field-minute": "минута",
	"field-month-narrow-relative+-1": "в пр. мес.",
	"field-tue-narrow-relative+0": "в этот вт.",
	"field-tue-narrow-relative+1": "в след. вт.",
	"field-thu-short-relative+0": "в этот чт.",
	"field-day-short-relative+-1": "вчера",
	"field-thu-short-relative+1": "в след. чт.",
	"field-day-relative+0": "сегодня",
	"field-day-short-relative+-2": "позавчера",
	"field-day-relative+1": "завтра",
	"field-week-narrow-relative+0": "на эт. нед.",
	"field-day-relative+2": "послезавтра",
	"field-week-narrow-relative+1": "на след. нед.",
	"field-wed-narrow-relative+-1": "в прош. ср.",
	"field-year-narrow": "г.",
	"field-era-short": "эра",
	"field-year-narrow-relative+0": "в эт. г.",
	"field-tue-relative+0": "в этот вторник",
	"field-year-narrow-relative+1": "в сл. г.",
	"field-tue-relative+1": "в следующий вторник",
	"field-weekdayOfMonth": "день недели в месяце",
	"field-second-short": "сек.",
	"field-weekdayOfMonth-narrow": "дн. нед. в мес.",
	"field-week-relative+0": "на этой неделе",
	"field-month-relative+0": "в этом месяце",
	"field-week-relative+1": "на следующей неделе",
	"field-month-relative+1": "в следующем месяце",
	"field-sun-narrow-relative+0": "в это вс.",
	"field-mon-short-relative+0": "в этот пн.",
	"field-sun-narrow-relative+1": "в след. вс.",
	"field-mon-short-relative+1": "в след. пн.",
	"field-second-relative+0": "сейчас",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"eraNames": [
		"до Диоклетиана",
		"от Диоклетиана"
	],
	"field-weekOfMonth": "неделя месяца",
	"field-month-short": "мес.",
	"field-day": "день",
	"field-dayOfYear-short": "дн. года",
	"field-year-relative+-1": "в прошлом году",
	"field-sat-short-relative+-1": "в прош. сб.",
	"field-hour-relative+0": "в этот час",
	"field-wed-relative+-1": "в прошлую среду",
	"field-sat-narrow-relative+-1": "в прош. сб.",
	"field-second": "секунда",
	"field-hour-short-relative+0": "в этот час",
	"field-quarter": "квартал",
	"field-week-short": "нед.",
	"field-day-narrow-relative+0": "сегодня",
	"field-day-narrow-relative+1": "завтра",
	"field-day-narrow-relative+2": "послезавтра",
	"field-tue-short-relative+0": "в этот вт.",
	"field-tue-short-relative+1": "в след. вт.",
	"field-month-short-relative+-1": "в прошлом мес.",
	"field-mon-relative+-1": "в прошлый понедельник",
	"field-month": "месяц",
	"field-day-narrow": "дн.",
	"field-minute-short": "мин.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "в эту сб.",
	"field-sat-short-relative+1": "в след. сб.",
	"eraAbbr": [
		"до Диокл.",
		"от Диокл."
	],
	"field-second-narrow": "с",
	"field-mon-relative+0": "в этот понедельник",
	"field-mon-relative+1": "в следующий понедельник",
	"field-day-narrow-relative+-1": "вчера",
	"field-year-short": "г.",
	"field-day-narrow-relative+-2": "позавчера",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-quarter-relative+-1": "в прошлом квартале",
	"field-dayperiod-narrow": "AM/PM",
	"field-week-narrow-relative+-1": "на пр. нед.",
	"field-dayOfYear": "день года",
	"field-sat-relative+-1": "в прошлую субботу",
	"field-hour": "час",
	"months-format-wide": [
		"тот",
		"бабэ",
		"хатур",
		"кихак",
		"тубэ",
		"амшир",
		"барамхат",
		"бармуда",
		"башнас",
		"бауна",
		"абиб",
		"мисра",
		"наси"
	],
	"field-month-relative+-1": "в прошлом месяце",
	"field-quarter-short": "кв.",
	"field-sat-narrow-relative+0": "в эту сб.",
	"field-fri-relative+0": "в эту пятницу",
	"field-sat-narrow-relative+1": "в след. сб.",
	"field-fri-relative+1": "в следующую пятницу",
	"field-month-narrow-relative+0": "в эт. мес.",
	"field-month-narrow-relative+1": "в след. мес.",
	"field-sun-short-relative+0": "в это вс.",
	"field-sun-short-relative+1": "в след. вс.",
	"field-week-relative+-1": "на прошлой неделе",
	"field-quarter-short-relative+-1": "последний кв.",
	"months-format-abbr": [
		"тот",
		"бабэ",
		"хатур",
		"кихак",
		"тубэ",
		"амшир",
		"барамхат",
		"бармуда",
		"башнас",
		"бауна",
		"абиб",
		"мисра",
		"наси"
	],
	"field-quarter-relative+0": "в текущем квартале",
	"field-minute-relative+0": "в эту минуту",
	"field-quarter-relative+1": "в следующем квартале",
	"field-wed-short-relative+-1": "в прош. ср.",
	"field-thu-short-relative+-1": "в прош. чт.",
	"field-year-narrow-relative+-1": "в пр. г.",
	"field-mon-narrow-relative+-1": "в прош. пн.",
	"field-thu-narrow-relative+-1": "в прош. чт.",
	"field-tue-narrow-relative+-1": "в прош. вт.",
	"field-weekOfMonth-short": "нед. месяца",
	"field-wed-short-relative+0": "в эту ср.",
	"months-standAlone-wide": [
		"тот",
		"бабэ",
		"хатур",
		"кихак",
		"тубэ",
		"амшир",
		"барамхат",
		"бармуда",
		"башнас",
		"бауна",
		"абиб",
		"мисра",
		"наси"
	],
	"field-wed-short-relative+1": "в след. ср.",
	"field-sun-relative+-1": "в прошлое воскресенье",
	"field-weekday": "день недели",
	"field-day-short-relative+0": "сегодня",
	"field-quarter-narrow-relative+0": "тек. кв.",
	"field-day-short-relative+1": "завтра",
	"field-sat-relative+0": "в эту субботу",
	"field-quarter-narrow-relative+1": "след. кв.",
	"field-day-short-relative+2": "послезавтра",
	"field-sat-relative+1": "в следующую субботу",
	"field-week-short-relative+0": "на этой нед.",
	"field-week-short-relative+1": "на следующей нед.",
	"months-standAlone-abbr": [
		"тот",
		"бабэ",
		"хатур",
		"кихак",
		"тубэ",
		"амшир",
		"барамхат",
		"бармуда",
		"башнас",
		"бауна",
		"абиб",
		"мисра",
		"наси"
	],
	"field-dayOfYear-narrow": "дн. года",
	"field-month-short-relative+0": "в этом мес.",
	"field-month-short-relative+1": "в следующем мес.",
	"field-weekdayOfMonth-short": "дн. нед. в месяце",
	"field-zone-narrow": "час. пояс",
	"field-thu-narrow-relative+0": "в этот чт.",
	"field-thu-narrow-relative+1": "в след. чт.",
	"field-sun-narrow-relative+-1": "в прош. вс.",
	"field-mon-short-relative+-1": "в прош. пн.",
	"field-thu-relative+0": "в этот четверг",
	"field-thu-relative+1": "в следующий четверг",
	"field-fri-short-relative+-1": "в прош. пт.",
	"field-thu-relative+-1": "в прошлый четверг",
	"field-week": "неделя",
	"field-wed-narrow-relative+0": "в эту ср.",
	"field-wed-narrow-relative+1": "в след. ср.",
	"field-quarter-narrow-relative+-1": "посл. кв.",
	"field-year-short-relative+0": "в этом г.",
	"field-dayperiod-short": "AM/PM",
	"field-year-short-relative+1": "в след. г.",
	"field-fri-short-relative+0": "в эту пт.",
	"field-fri-short-relative+1": "в след. пт.",
	"field-week-short-relative+-1": "на прошлой нед.",
	"field-hour-narrow-relative+0": "в этот час",
	"field-hour-short": "ч",
	"field-zone-short": "час. пояс",
	"field-month-narrow": "мес.",
	"field-hour-narrow": "ч",
	"field-fri-narrow-relative+-1": "в прош. пт.",
	"field-year-relative+0": "в этом году",
	"field-year-relative+1": "в следующем году",
	"field-era-narrow": "эра",
	"field-fri-relative+-1": "в прошлую пятницу",
	"eraNarrow": [
		"до Диокл.",
		"от Диокл."
	],
	"field-tue-short-relative+-1": "в прош. вт.",
	"field-minute-narrow": "мин",
	"field-mon-narrow-relative+0": "в этот пн.",
	"field-mon-narrow-relative+1": "в след. пн.",
	"field-year-short-relative+-1": "в прошлом г.",
	"field-zone": "часовой пояс",
	"field-weekOfMonth-narrow": "нед. мес.",
	"field-weekday-narrow": "дн. нед.",
	"field-quarter-narrow": "кв.",
	"field-sun-short-relative+-1": "в прош. вс.",
	"field-day-relative+-1": "вчера",
	"field-day-relative+-2": "позавчера",
	"field-weekday-short": "дн. недели",
	"field-sun-relative+0": "в это воскресенье",
	"field-sun-relative+1": "в следующее воскресенье",
	"field-day-short": "дн.",
	"field-week-narrow": "нед.",
	"field-era": "эра",
	"field-fri-narrow-relative+0": "в эту пт.",
	"field-fri-narrow-relative+1": "в след. пт."
}
//end v1.x content
);
